@@ -1298,9 +1298,6 @@ test_find_attributes (void)
 int
 main (int argc, char **argv)
 {
-#if !GLIB_CHECK_VERSION(2,35,0)
-	g_type_init ();
-#endif
 	g_test_init (&argc, &argv, NULL);
 
 	g_test_add_func ("/gck/value/to_boolean", test_value_to_boolean);
