@@ -22,12 +22,11 @@
 
 #include "config.h"
 
-#include "mock-interaction.h"
-
 #include "gck/gck.h"
 #include "gck/gck-test.h"
 
 #include "egg/egg-testing.h"
+#include "egg/mock-interaction.h"
 
 #include <glib.h>
 
