@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -26,9 +24,10 @@
 #include "gcr-comparable.h"
 #include "gcr-icons.h"
 #include "gcr-internal.h"
-#include "gcr-oids.h"
 #include "gcr-subject-public-key.h"
 
+#include "gcr/gcr-oids.h"
+
 #include "egg/egg-asn1x.h"
 #include "egg/egg-asn1-defs.h"
 #include "egg/egg-dn.h"
@@ -200,8 +199,16 @@ digest_certificate (GcrCertificate *self, GChecksumType type)
 	return digest;
 }
 
-static gchar*
-calculate_markup (GcrCertificate *self)
+/**
+ * gcr_certificate_get_markup_text:
+ * @self: a certificate
+ *
+ * Calculate a GMarkup string for displaying this certificate.
+ *
+ * Returns: (transfer full): the markup string
+ */
+gchar *
+gcr_certificate_get_markup_text (GcrCertificate *self)
 {
 	gchar *label = NULL;
 	gchar *issuer;
@@ -254,7 +261,7 @@ gcr_certificate_default_init (GcrCertificateIface *iface)
 		CERTIFICATE_INFO = g_quark_from_static_string ("_gcr_certificate_certificate_info");
 
 		/**
-		 * GcrCertificate:label: (allow-none)
+		 * GcrCertificate:label:
 		 *
 		 * A readable label for this certificate.
 		 */
@@ -272,7 +279,7 @@ gcr_certificate_default_init (GcrCertificateIface *iface)
 		                              "", G_PARAM_READABLE));
 
 		/**
-		 * GcrCertificate:markup: (allow-none)
+		 * GcrCertificate:markup:
 		 *
 		 * GLib markup to describe the certificate
 		 */
@@ -290,7 +297,7 @@ gcr_certificate_default_init (GcrCertificateIface *iface)
 		                              G_TYPE_ICON, G_PARAM_READABLE));
 
 		/**
-		 * GcrCertificate:subject: (allow-none)
+		 * GcrCertificate:subject:
 		 *
 		 * Common name part of the certificate subject
 		 */
@@ -299,7 +306,7 @@ gcr_certificate_default_init (GcrCertificateIface *iface)
 		                                "", G_PARAM_READABLE));
 
 		/**
-		 * GcrCertificate:issuer: (allow-none)
+		 * GcrCertificate:issuer:
 		 *
 		 * Common name part of the certificate issuer
 		 */
@@ -308,7 +315,7 @@ gcr_certificate_default_init (GcrCertificateIface *iface)
 		                                "", G_PARAM_READABLE));
 
 		/**
-		 * GcrCertificate:expiry: (allow-none)
+		 * GcrCertificate:expiry:
 		 *
 		 * The expiry date of the certificate
 		 */
@@ -400,9 +407,9 @@ gcr_certificate_compare (GcrComparable *first, GcrComparable *other)
  *
  * Gets the raw DER data for an X.509 certificate.
  *
- * Returns: (array length=n_data): raw DER data of the X.509 certificate
+ * Returns: (transfer none) (array length=n_data): raw DER data of the X.509 certificate
  **/
-const guchar *
+const guint8 *
 gcr_certificate_get_der_data (GcrCertificate *self,
                               gsize *n_data)
 {
@@ -1004,8 +1011,8 @@ gcr_certificate_get_icon (GcrCertificate *self)
 /**
  * gcr_certificate_get_basic_constraints:
  * @self: the certificate
- * @is_ca: (allow-none): location to place a %TRUE if is an authority
- * @path_len: (allow-none): location to place the max path length
+ * @is_ca: (out) (allow-none): location to place a %TRUE if is an authority
+ * @path_len: (out) (allow-none): location to place the max path length
  *
  * Get the basic constraints for the certificate if present. If %FALSE is
  * returned then no basic constraints are present and the @is_ca and
@@ -1185,7 +1192,7 @@ gcr_certificate_mixin_get_property (GObject *obj, guint prop_id,
 		g_value_set_string (value, _("Certificate"));
 		break;
 	case PROP_MARKUP:
-		g_value_take_string (value, calculate_markup (cert));
+		g_value_take_string (value, gcr_certificate_get_markup_text (cert));
 		break;
 	case PROP_ISSUER:
 		g_value_take_string (value, gcr_certificate_get_issuer_name (cert));
