@@ -21,8 +21,6 @@
 
 #include "config.h"
 
-#define DEBUG_FLAG GCR_DEBUG_IMPORT
-#include "gcr-debug.h"
 #include "gcr-deprecated-base.h"
 #include "gcr-importer.h"
 #include "gcr-internal.h"
@@ -232,11 +230,9 @@ gcr_importer_create_for_parsed (GcrParsed *parsed)
 
 	seen = g_hash_table_new (g_direct_hash, g_direct_equal);
 
-	if (_gcr_debugging) {
-		gchar *a = gck_attributes_to_string (attrs);
-		_gcr_debug ("looking for importer for: %s", a);
-		g_free (a);
-	}
+	gchar *a = gck_attributes_to_string (attrs);
+	g_debug ("looking for importer for: %s", a);
+	g_free (a);
 
 	for (i = 0; i < registered_importers->len; ++i) {
 		registered = &(g_array_index (registered_importers, GcrRegistered, i));
@@ -251,12 +247,10 @@ gcr_importer_create_for_parsed (GcrParsed *parsed)
 			}
 		}
 
-		if (_gcr_debugging) {
-			gchar *a = gck_attributes_to_string (registered->attrs);
-			_gcr_debug ("importer %s %s: %s", g_type_name (registered->importer_type),
-			            matched ? "matched" : "didn't match", a);
-			g_free (a);
-		}
+		gchar *a = gck_attributes_to_string (registered->attrs);
+		g_debug ("importer %s %s: %s", g_type_name (registered->importer_type),
+		         matched ? "matched" : "didn't match", a);
+		g_free (a);
 
 		if (matched) {
 			if (check_if_seen_or_add (seen, GUINT_TO_POINTER (registered->importer_type)))
