@@ -271,7 +271,7 @@ gcr_unlock_renderer_render (GcrRenderer *renderer,
 		g_free (display);
 
 		if (self->pv->label)
-			display = g_strdup_printf (_("The contents of '%s' are locked. In order to view the contents, enter the correct password."),
+			display = g_strdup_printf (_("The contents of “%s” are locked. In order to view the contents, enter the correct password."),
 			                           self->pv->label);
 		else
 			display = g_strdup (_("The contents are locked. In order to view the contents, enter the correct password."));
